@@ -2,7 +2,7 @@
  * Copyright 2013 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation; version 3.
  *
  * This program is distributed in the hope that it will be useful,
@@ -16,10 +16,13 @@
  * Author: Lars Uebernickel <lars.uebernickel@canonical.com>
  */
 
+
 #include "plugin.h"
 #include "gsettings-qml.h"
 
 void GSettingsQmlPlugin::registerTypes(const char *uri)
 {
     qmlRegisterType<GSettingsQml>(uri, 1, 0, "GSettings");
+    qmlRegisterUncreatableType<GSettingsSchemaQml>(uri, 1, 0, "GSettingsSchema",
+                                                   "GSettingsSchema can only be used inside of a GSettings component");
 }
