@@ -21,7 +21,7 @@
 class GSettingsQmlPlugin: public QQmlExtensionPlugin
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "com.canonical.GSettings")
+    Q_PLUGIN_METADATA(IID "com.ubports.GSettings")
 
 public:
     void registerTypes(const char *uri);
